from __future__ import absolute_import, division, print_function, unicode_literals

from datetime import datetime, date
from dateutil import parser

from amaascore.assets.asset import Asset


class RealAsset(Asset):

    def __init__(self, asset_manager_id, asset_id, asset_issuer_id=None, asset_status='Active', description='',
                 country_id=None, venue_id=None, currency=None, links=None, references=None, *args, **kwargs):
        if not hasattr(self, 'asset_class'):  # A more specific child class may have already set this
            self.asset_class = 'RealAsset'
        super(RealAsset, self).__init__(asset_manager_id=asset_manager_id, asset_id=asset_id, fungible=False,
                                        asset_issuer_id=asset_issuer_id, asset_status=asset_status,
                                        description=description, country_id=country_id, venue_id=venue_id,
                                        currency=currency, links=links, references=references,
                                        *args, **kwargs)



from __future__ import absolute_import, division, print_function, unicode_literals

from amaascore.parties.company import Company


class AssetManager(Company):

    def __init__(self, asset_manager_id, party_id, base_currency=None, description='', party_status='Active',
                 addresses=None, emails=None, links=None, references=None,
                 *args, **kwargs):
        super(AssetManager, self).__init__(asset_manager_id=asset_manager_id, party_id=party_id,
                                           base_currency=base_currency,
                                           description=description, party_status=party_status,
                                           addresses=addresses, emails=emails,
                                           links=links, references=references, *args, **kwargs)
